# (C) Copyright 2023- ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
#


try:
    # NOTE: the `version.py` file must not be present in the git repository
    #   as it is generated by setuptools at install time
    from .version import __version__
except ImportError:  # pragma: no cover
    # Local copy or not installed with setuptools
    __version__ = "999"

import earthkit.data as data
import earthkit.maps as maps
import earthkit.meteo as meteo
import earthkit.plots as plots
import earthkit.regrid as regrid

__all__ = [
    "data",
    "maps",
    "meteo",
    "plots",
    "regrid",
    "__version__",
]
